> [!info] Considerations
> 
> 
> * The terms **process** and **habit** are used interchangeably here, but they mean the same thing.
> * The Tiny Habits Model heavily inspired the framework.
> 


## What Are Processes and Why Bother?

Processes are recurring tasks. They are important because they represent the smallest actionable components of our daily lives that, if targeted, can significantly advance us toward achieving our goals. Unlike one-off tasks, which may have a large scope but limited duration, even the smallest habits maintained over decades can have a profound impact.

Processes enable us to change our personas, stop destructive behaviors, and build a foundation for long-term growth.

## The Basics of Habit Formation

Habits are formed when a prompt triggers an action that is easy enough to perform consistently and has enough **impact** to drive motivation.

### Prompts

A prompt reminds you to perform the process, and different prompts serve distinct purposes. Ideally, you want to create as many _anchor prompts_ as possible and rely less on _context prompts_.

* **Context prompts** are reminders based on situations or environments, like checking a to-do list or receiving a notification.
* **Anchor prompts** are actions that remind you to carry out the process. First, search for the action that has the same time, recurrence, and place as the new behavior. Once you find it, practice this new combination multiple times to reinforce the connection.

> [!tip] third type
> 
> 
> If you want to reduce reliance on context prompts but can't find an action to anchor the habit to, use an intermediary prompt type—a short-term reminder. Most task managers allow you to set repeating reminders based on days or frequency. Use these reminders temporarily to train yourself to remember the habit. After that period, the reminders can be turned off, and you'll have successfully created an anchor-based habit.
> 


There are different types of processes based on the prompt type:

* **Context processes**
    * Processes are initiated only after seeing them in Obsidian. These processes need a recurrence and should be postponed when completed (make sure to use the toolbar button "repeat" to postpone easily). Check [Obsidian implementation](Resources/Obsidian%20implementation.md) for more details.
    * Processes triggered by real-life context cues (notifications, locations, etc.). This sub-type doesn't need recurrence in Obsidian; it just needs documentation.
* **Anchor processes** are initiated in real life after anchor actions. These don't require recurrence in Obsidian; they only require documentation.

### Actions and Ease

1. Since the goal of a habit can be achieved through various actions, you have the flexibility to choose the actions that suit you best, considering motivation and impact.
2. After choosing your actions, make them as easy as possible:
    1. Find some training, tools, or resources to make the action easier.
    2. If you can't, shrink the behavior by breaking it down as much as possible. And then build upon it to reach the originally intended behavior.
    3. If you can't, focus on the _starter step_—the smallest, simplest action that sets the behavior in motion. The goal is to take the tiniest possible step that brings you closer to the desired outcome.

> [!tip] Remember this when choosing an action:
> 
> 
> * You aim to make it easy, so choosing a motivating but initially challenging task is acceptable.
> * The ease of the action changes over time as your brain adapts to the behavior.
> 


### Celebration

The final component of habit formation is the celebration phase, which signals your brain that the habit should be repeated. You can choose any celebratory phrase or action, but saying "Alhamdulillah" is particularly meaningful. This provides the dual benefit of thanking Allah while reinforcing the habit in your mind—a true "win-win."

## The Basics of Behavior Change

In this context, "behavior change" refers to altering existing negative behaviors representing undesirable traits in our system rather than refining non-working habits. To achieve this, try to **stop** the associated bad habits individually. If this proves ineffective, try **swapping** the bad habits with positive ones. Here's a framework for approaching this:

* **Stopping the bad habit:**
    * Remove or avoid the prompt by changing your environment.
    * Make the action harder or impossible to perform, such as by introducing obstacles, eliminating access to tools that support the habit, or creating conflicting routines.
* **Swapping the bad habit:**
    * Redirect the prompt used for the bad behavior to perform a suitable positive behavior.
    * Make the bad behavior harder while making the intended good behavior easier by adjusting your environment or routine to favor the positive behavior.
    * Adjust until you find a suitable replacement behavior that disrupts the bad habit.

> [!info] OR/AND
> 
> 
> Try each method independently or combine them if that works better for you.
> 


## Intersection with Obsidian

When maintaining processes inside Obsidian, you should use the [`step` property](Resources/Obsidian%20implementation.md) to describe what you will do with each process. This helps you manage multiple processes that require the same type of solution simultaneously. This is done by grouping them based on the `step` property under the "process" tab on the Homepage. Based on the framework described above, here are the main situations you may encounter within Obsidian:

1. **Making the action easier**: When a process doesn't work the first time you set it up or when you find ways to improve its ease of execution.
2. **Finding the right behavior**: You need to identify a new behavior for non-working processes or processes that weren't implemented due to poor action choices.
3. **Changing the prompt**: When you struggle to remember to do the process at the right time.
4. **Removing or avoiding the prompt**: When you want to stop remembering to engage in an unwanted behavior.
5. **Retargeting the prompt**: When you want to use the same prompt for a more useful behavior.
6. **Making the action harder**: When you want to stop an unwanted behavior with a more restrictive approach or when you need to swap the behavior for a better one, you will also need to make the alternative behavior easier, so add the first situation alongside this one.
